@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/kms/KMS_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/kms/KMS_EXPORTS.h>
 
-namespace Aws
-{
-namespace KMS
-{
-namespace Model
-{
-  enum class RotationType
-  {
-    NOT_SET,
-    AUTOMATIC,
-    ON_DEMAND
-  };
+namespace Aws {
+namespace KMS {
+namespace Model {
+enum class RotationType { NOT_SET, AUTOMATIC, ON_DEMAND };
 
-namespace RotationTypeMapper
-{
+namespace RotationTypeMapper {
 AWS_KMS_API RotationType GetRotationTypeForName(const Aws::String& name);
 
 AWS_KMS_API Aws::String GetNameForRotationType(RotationType value);
-} // namespace RotationTypeMapper
-} // namespace Model
-} // namespace KMS
-} // namespace Aws
+}  // namespace RotationTypeMapper
+}  // namespace Model
+}  // namespace KMS
+}  // namespace Aws
